==> haskell-cipher-aes-0.2.11-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-FRyhJ05rCDW18ACC9UuHoq
key: cipher-aes-0.2.11-FRyhJ05rCDW18ACC9UuHoq
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
abi: 9cf8d755ffdaf759599464554b36ea95
exposed: True
exposed-modules:
    Crypto.Cipher.AES
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-FRyhJ05rCDW18ACC9UuHoq
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    securemem-0.1.10-47XaaCnM3DyGgdDgPxhm0Y
    crypto-cipher-types-0.0.9-CWRnyUrf3Y13otvenAhiW3
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             securemem-0.1.10-47XaaCnM3DyGgdDgPxhm0Y=d07f4cef1c048aa78f9aab076120bd67
             crypto-cipher-types-0.0.9-CWRnyUrf3Y13otvenAhiW3=cb87066ae33bf9a24024a1848d60cb54
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes-0.2.11-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-tIPx0sjJRKAIH3A8nJYa
key: cipher-aes-0.2.11-tIPx0sjJRKAIH3A8nJYa
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
abi: 4a9c7712ebcf66b620665b52c65612bf
exposed: True
exposed-modules:
    Crypto.Cipher.AES
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-tIPx0sjJRKAIH3A8nJYa
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    securemem-0.1.10-1nAkOK0asxn9EaBRVm9Joj
    crypto-cipher-types-0.0.9-EWk0jumiXj3KrML8ob3vUH
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             securemem-0.1.10-1nAkOK0asxn9EaBRVm9Joj=2d5e27f5182c4272f9cc461783b2d851
             crypto-cipher-types-0.0.9-EWk0jumiXj3KrML8ob3vUH=b606797ba90c9dd59b736fcc08c884f2
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
